#!/usr/bin/python
###############################################################################
#                                                                             #
# Fireinfo                                                                    #
# Copyright (C) 2010, 2011 IPFire Team (www.ipfire.org)                       #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

import os
import string


class Device(object):
	def __init__(self, path):
		self.path=path
		self._uevent={}	
		with open(os.path.join(path, "uevent")) as f:
			for line in f.readlines():
				key, val = line.split("=")
				self._uevent[key]=val.rstrip().lower()
		
	@property
	def driver(self):
		return self._uevent.get("DRIVER", None)

			
class PCIDevice(Device):
	subsystem = "pci"
	
	@property
	def model(self):
		return self._uevent['PCI_ID'].split(":")[1]
		
	@property
	def vendor(self):
		return self._uevent['PCI_ID'].split(":")[0]

	@property
	def deviceclass(self):
		return self._uevent['PCI_CLASS']

	@property
	def sub_vendor(self):
		return self._uevent["PCI_SUBSYS_ID"].split(":")[0]

	@property
	def sub_model(self):
		return self._uevent["PCI_SUBSYS_ID"].split(":")[1]


class USBDevice(Device):
	subsystem = "usb"
	
	def pad(self, s):
		while len(s) < 4:
			s = "0"+s
		return s
		
	
	@property
	def vendor(self):
		return self.pad(self._uevent['PRODUCT'].split("/")[0])

	@property
	def model(self):
		return self.pad(self._uevent['PRODUCT'].split("/")[1])

	@property
	def deviceclass(self):
		return self._uevent.get("INTERFACE", None)


	
